==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/es/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Información</strong>',
  '<strong>Profile</strong> Permissions' => 'Permisos de <strong>perfil</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>Ajustes</strong> y Configuración',
  '<strong>User</strong> administration' => 'Administración de <strong>Usuarios</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Advertencia:</strong> ¡Todas las configuraciones de permisos de perfiles individuales se restablecen a los valores predeterminados!',
  'Accept user: <strong>{displayName}</strong> ' => 'Aceptar usuario: <strong>{displayName}</strong>',
  'Account' => 'Cuenta',
  'Account Request for \'{displayName}\' has been approved.' => 'La solicitud de cuenta para \'{displayName}\' ha sido aprobada.',
  'Account Request for \'{displayName}\' has been declined.' => 'La solicitud de cuenta para \'{displayName}\' ha sido denegada.',
  'Actions' => 'Acciones',
  'Active users' => 'Usuarios activos',
  'Add Groups...' => 'Agregar grupos...',
  'Add a separate page for the group to the directory.' => 'Añadir al directorio una página aparte para el grupo.',
  'Add new category' => 'Añadir nueva categoría',
  'Add new field' => 'Añadir nuevo campo',
  'Add new group' => 'Agregar un nuevo grupo',
  'Add new members...' => 'Agregar nuevos usuarios...',
  'Add new user' => 'Añadir nuevo usuario',
  'Administrator group could not be deleted!' => '¡No se pudo eliminar el grupo de administradores!',
  'All open registration invitations were successfully deleted.' => 'Todas las invitaciones a registro pendientes han sido borradas con éxito.',
  'All the personal data of this user will be irrevocably deleted.' => 'Todos los datos personales de este usuario serán borrados irrevocablemente.',
  'Allow' => 'Permitir',
  'Allow users to set individual permissions for their own profile?' => '¿Permitir que los usuarios establezcan permisos individuales para su propio perfil?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Permitir acceso limitado para usuarios no autentificados (invitados)',
  'Applied to new or existing users without any other group membership.' => 'Se aplica a usuarios nuevos o existentes sin ninguna otra membresía de grupo.',
  'Are you really sure that you want to disable this user?' => '¿Estás seguro de querer deshabilitar este usuario?',
  'Are you really sure that you want to enable this user?' => '¿Estás seguro de querer habilitar este usuario?',
  'Are you really sure that you want to impersonate this user?' => '¿Estás seguro de querer asumir la identidad de este usuario?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '¿Estas realmente seguro? Los usuarios que no están asignados a otro grupo se asignan automáticamente al grupo predeterminado.',
  'Are you sure that you want to delete following user?' => '¿Estás seguro de querer borrar el siguiente usuario?',
  'Cancel' => 'Cancelar',
  'Click here to review' => 'Haz clic aqui para revisar',
  'Confirm user deletion' => 'Confirme el borrado del usuario',
  'Could not load category.' => 'No se pudo cargar la categoría.',
  'Create new group' => 'Crear nuevo grupo',
  'Create new profile category' => 'Crear nueva categoría de perfil',
  'Create new profile field' => 'Crear nuevo campo de perfil',
  'Deactivate' => 'Desactivar',
  'Deactivate individual profile permissions?' => '¿Desactivar los permisos de perfil individual?',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Declinar y borrar usuario: <strong>{displayName}</strong>',
  'Default' => 'Predeterminado',
  'Default Profile Permissions' => 'Permisos de perfil predeterminados',
  'Default content of the registration approval email' => 'Contenido por defecto del mensaje de aceptación del registro',
  'Default content of the registration denial email' => 'Contenido por defecto del mensaje de denegación del registro',
  'Default groups can not be deleted!' => '¡Los grupos predeterminados no se pueden eliminar!',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Tiempo de inactividad antes de cerrar sesión (en segundos, opcional)',
  'Default user profile visibility' => 'Visibilidad del perfil de usuario por defecto',
  'Delete' => 'Borrar',
  'Delete All' => 'Borrar todas',
  'Delete all contributions of this user' => 'Borrar todas las contribuciones de este usuario',
  'Delete invitation' => 'Borrar invitación',
  'Delete invitation?' => '¿Borrar invitación?',
  'Delete spaces which are owned by this user' => 'Borrar los espacios que son propiedad de este usuario',
  'Deleted invitation' => 'Borrar invitación',
  'Deleted users' => 'Borrar usuarios',
  'Disable' => 'Deshabilitar',
  'Disabled' => 'Deshabilitado',
  'Disabled users' => 'Deshabilitar usuarios',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'No modifique los marcadores como {displayName} si quiere que el sistema los rellene automáticamente. Para reiniciar los campos de contenido de correo electrónico a los valores por defecto del sistema déjelos vacíos.',
  'Edit category' => 'Editar categoria',
  'Edit profile category' => 'Editar categoría de perfil',
  'Edit profile field' => 'Editar campo de perfil',
  'Edit user: {name}' => 'Editar usuario: {name}',
  'Enable' => 'Habilitar',
  'Enable individual profile permissions' => 'Habilitar permisos de perfil individual',
  'Enabled' => 'Habilitado',
  'Group Manager' => 'Administrador de Grupo',
  'Group not found!' => '¡Grupo no encontrado!',
  'Group user not found!' => '¡Usuario de grupo no encontrado!',
  'Groups' => 'Grupos',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => 'Hola {displayName}, <br><br> Su cuenta ha sido activada. <br><br> Haga clic aquí para iniciar sesión:<br> {loginLink}<br><br> Saludos cordiales<br> {AdminName} <br><br>',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => 'Hola {displayName},<br><br> Se ha rechazado su solicitud de cuenta.<br><br> Saludos cordiales <br> {AdminName} <br><br>',
  'Here you can create or edit profile categories and fields.' => 'Aquí puedes crear o editar categorías y campos de perfil.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Si no se permiten permisos de perfil individual, la siguiente configuración no se puede cambiar para todos los usuarios. Si se permiten permisos de perfil individual, la configuración solo se establece como valores predeterminados que los usuarios pueden personalizar. Las siguientes entradas se muestran en el mismo formulario en la configuración del perfil de usuario:',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Si no está seleccionada esta opción, la propiedad de los espacios será transferida a tu cuenta.',
  'Impersonate' => 'Asumir identidad',
  'Include captcha in registration form' => 'Incluir captcha en el formulario de registro',
  'Invite not found!' => '¡No se ha encontrado la invitación!',
  'Last login' => 'Último registro',
  'List pending registrations' => 'Lista de registros pendientes',
  'Make the group selectable at registration.' => 'Permitir que se seleccione el grupo durante el registro.',
  'Manage group: {groupName}' => 'Administrar grupo: {groupName}',
  'Manage groups' => 'Gestionar grupos',
  'Manage profile attributes' => 'Gestionar atributos de perfil',
  'Member since' => 'Miembro desde',
  'Members' => 'Miembros',
  'Members can invite external users by email' => 'Los miembros pueden invitar a usuarios externos por correo electrónico',
  'Message' => 'Mensaje',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'El valor mínimo son 20 segundos. Si la casilla está vacía, la sesión se terminará automáticamente después de 1400 segundos (24 minutos) si no hay actividad.',
  'New approval requests' => 'Nuevas peticiones de aprobación',
  'New users can register' => 'Los usuarios anónimos pueden registrarse',
  'No' => 'No',
  'No value found!' => '¡Valor no encontrado!',
  'One or more user needs your approval as group admin.' => 'Uno o más usuarios necesita tu aprobación como administrador del grupo.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Sólo aplicable cuando hay acceso limitado activado para los usuarios no autentificados. Sólo afecta a los usuarios nuevos.',
  'Overview' => 'Resumen',
  'Password' => 'Clave',
  'Pending approvals' => 'Aprobaciones pendientes',
  'Pending user approvals' => 'Aprobaciones de usuario pendientes',
  'Permanently delete' => 'Borrar permanentemente',
  'Permissions' => 'Permisos',
  'Profile Permissions' => 'Permisos de perfil',
  'Profiles' => 'Perfiles',
  'Remove from group' => 'Remover del grupo',
  'Require group admin approval after registration' => 'Requerir aprobación del administrador del grupo después de registrarse',
  'Resend invitation email' => 'Reenviar mensaje de invitación',
  'Save' => 'Guardar',
  'Search by name, email or id.' => 'Buscar por nombre, email o id',
  'Select Groups' => 'Seleccionar grupos',
  'Send & save' => 'Enviar y guardar',
  'Send invitation email' => 'Enviar mensaje de invitación',
  'Send invitation email again?' => '¿Reenviar el mensaje de invitación?',
  'Send invite' => 'Enviar invitación',
  'Send notifications to users when added to or removed from the group.' => 'Enviar notificaciones a los usuarios cuando se les añada o elimine del grupo.',
  'Settings' => 'Ajustes',
  'Show group selection at registration' => 'Mostrar selección de grupo al registrarse',
  'Subject' => 'Asunto',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'Se actualizarán las pertenencias al espacio de todos los grupos. Esta operación puede tardar varios minutos.',
  'The following list contains all pending sign-ups and invites.' => 'La lista siguiente contiene todos los registros e invitaciones pendientes.',
  'The following list contains all registered users awaiting an approval.' => 'La siguiente lista contiene todos los usuarios registrados que esperan una aprobación.',
  'The selected invitations have been successfully deleted!' => 'Se han eliminado con éxito las invitaciones pendientes seleccionadas.',
  'The user is the owner of these spaces:' => 'El usuario es el propietario de estos espacios:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Esta opción le permite determinar si los usuarios pueden establecer permisos individuales para sus propios perfiles.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Esta vista contiene una lista de cada usuario registrado con acciones para ver, editar y eliminar usuarios.',
  'This user owns no spaces.' => 'Este usuario no posee espacios.',
  'Unapproved' => 'Desaprobado',
  'User deletion process queued.' => 'Se ha encolado el proceso de borrado del usuario.',
  'User is already a member of this group.' => 'Este usuario ya es miembro de este grupo.',
  'User not found!' => '¡Usuario no encontrado!',
  'Users' => 'Usuarios',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Los usuarios pueden asignarse a diferentes grupos (por ejemplo, equipos, departamentos, etc.) con espacios estándar específicos, administradores de grupo y permisos.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Al utilizar esta opción cualquier contribución (p. ej. contenidos, comentarios o “me gusta”) de este usuario se borrará de forma irrecuperable.',
  'View profile' => 'Ver perfil',
  'Visible for members only' => 'Visible para miembros únicamente',
  'Visible for members+guests' => 'Visible para miembros + invitados',
  'Yes' => 'Sí',
  'You can only delete empty categories!' => '¡Sólo puedes borrar categorías vacias!',
  'You cannot delete yourself!' => '¡No te puedes borrar a tí mismo!',
  'never' => 'Nunca',
);

==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/admin/messages/es/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Información</strong>',
  '<strong>Profile</strong> Permissions' => 'Permisos de <strong>perfil</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>Ajustes</strong> y Configuración',
  '<strong>User</strong> administration' => 'Administración de <strong>Usuarios</strong>',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Advertencia:</strong> ¡Todas las configuraciones de permisos de perfiles individuales se restablecen a los valores predeterminados!',
  'Accept user: <strong>{displayName}</strong> ' => 'Aceptar usuario: <strong>{displayName}</strong>',
  'Account' => 'Cuenta',
  'Account Request for \'{displayName}\' has been approved.' => 'La solicitud de cuenta para \'{displayName}\' ha sido aprobada.',
  'Account Request for \'{displayName}\' has been declined.' => 'La solicitud de cuenta para \'{displayName}\' ha sido denegada.',
  'Actions' => 'Acciones',
  'Active users' => 'Usuarios activos',
  'Add Groups...' => 'Agregar grupos...',
  'Add new category' => 'Añadir nueva categoría',
  'Add new field' => 'Añadir nuevo campo',
  'Add new group' => 'Agregar un nuevo grupo',
  'Add new members...' => 'Agregar nuevos usuarios...',
  'Add new user' => 'Añadir nuevo usuario',
  'Administrator group could not be deleted!' => '¡No se pudo eliminar el grupo de administradores!',
  'All open registration invitations were successfully deleted.' => 'Todas las invitaciones a registro pendientes han sido borradas con éxito.',
  'All the personal data of this user will be irrevocably deleted.' => 'Todos los datos personales de este usuario serán borrados irrevocablemente.',
  'Allow' => 'Permitir',
  'Allow users to block each other' => 'Permitir que los usuarios se bloqueen entre sí',
  'Allow users to set individual permissions for their own profile?' => '¿Permitir que los usuarios establezcan permisos individuales para su propio perfil?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Permitir acceso limitado para usuarios no autentificados (invitados)',
  'Applied to new or existing users without any other group membership.' => 'Se aplica a usuarios nuevos o existentes sin ninguna otra membresía de grupo.',
  'Are you really sure that you want to disable this user?' => '¿Estás seguro de querer deshabilitar este usuario?',
  'Are you really sure that you want to enable this user?' => '¿Estás seguro de querer habilitar este usuario?',
  'Are you really sure that you want to impersonate this user?' => '¿Estás seguro de querer asumir la identidad de este usuario?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '¿Estas realmente seguro? Los usuarios que no están asignados a otro grupo se asignan automáticamente al grupo predeterminado.',
  'Are you sure that you want to delete following user?' => '¿Estás seguro de querer borrar el siguiente usuario?',
  'Cancel' => 'Cancelar',
  'Click here to review' => 'Haz clic aqui para revisar',
  'Confirm user deletion' => 'Confirme el borrado del usuario',
  'Could not load category.' => 'No se pudo cargar la categoría.',
  'Create new group' => 'Crear nuevo grupo',
  'Create new profile category' => 'Crear nueva categoría de perfil',
  'Create new profile field' => 'Crear nuevo campo de perfil',
  'Deactivate' => 'Desactivar',
  'Deactivate individual profile permissions?' => '¿Desactivar los permisos de perfil individual?',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Declinar y borrar usuario: <strong>{displayName}</strong>',
  'Default' => 'Predeterminado',
  'Default Profile Permissions' => 'Permisos de perfil predeterminados',
  'Default Sorting' => 'Orden por defecto',
  'Default content of the registration approval email' => 'Contenido por defecto del mensaje de aceptación del registro',
  'Default content of the registration denial email' => 'Contenido por defecto del mensaje de denegación del registro',
  'Default group can not be deleted!' => '¡El grupo por defecto no puede borrarse!',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Tiempo de inactividad antes de cerrar sesión (en segundos, opcional)',
  'Default user profile visibility' => 'Visibilidad del perfil de usuario por defecto',
  'Delete' => 'Borrar',
  'Delete All' => 'Borrar todas',
  'Delete all contributions of this user' => 'Borrar todas las contribuciones de este usuario',
  'Delete invitation' => 'Borrar invitación',
  'Delete invitation?' => '¿Borrar invitación?',
  'Delete spaces which are owned by this user' => 'Borrar los espacios que son propiedad de este usuario',
  'Deleted invitation' => 'Borrar invitación',
  'Deleted users' => 'Borrar usuarios',
  'Disable' => 'Deshabilitar',
  'Disabled' => 'Deshabilitado',
  'Disabled users' => 'Deshabilitar usuarios',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'No modifique los marcadores como {displayName} si quiere que el sistema los rellene automáticamente. Para reiniciar los campos de contenido de correo electrónico a los valores por defecto del sistema déjelos vacíos.',
  'Edit category' => 'Editar categoria',
  'Edit profile category' => 'Editar categoría de perfil',
  'Edit profile field' => 'Editar campo de perfil',
  'Edit user: {name}' => 'Editar usuario: {name}',
  'Enable' => 'Habilitar',
  'Enable individual profile permissions' => 'Habilitar permisos de perfil individual',
  'Enabled' => 'Habilitado',
  'First name' => 'Nombre',
  'Group Manager' => 'Administrador de Grupo',
  'Group not found!' => '¡Grupo no encontrado!',
  'Group user not found!' => '¡Usuario de grupo no encontrado!',
  'Groups' => 'Grupos',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => 'Hola {displayName}, Tu cuenta ha sido activada. Haz clic aquí para acceder:: {loginUrl} Gracias {AdminName}',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => 'hola {displayName}, Tu petición de cuenta ha sido rechazada. Gracias {AdminName}',
  'Here you can create or edit profile categories and fields.' => 'Aquí puedes crear o editar categorías y campos de perfil.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Si no se permiten permisos de perfil individual, la siguiente configuración no se puede cambiar para todos los usuarios. Si se permiten permisos de perfil individual, la configuración solo se establece como valores predeterminados que los usuarios pueden personalizar. Las siguientes entradas se muestran en el mismo formulario en la configuración del perfil de usuario:',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Si no está seleccionada esta opción, la propiedad de los espacios será transferida a tu cuenta.',
  'Impersonate' => 'Asumir identidad',
  'Include captcha in registration form' => 'Incluir captcha en el formulario de registro',
  'Information 1' => 'Información 1',
  'Information 2' => 'Información 2',
  'Information 3' => 'Información 3',
  'Invite not found!' => '¡No se ha encontrado la invitación!',
  'Last login' => 'Último registro',
  'Last name' => 'Apellido',
  'List pending registrations' => 'Lista de registros pendientes',
  'Make the group selectable at registration.' => 'Permitir que se seleccione el grupo durante el registro.',
  'Manage group: {groupName}' => 'Administrar grupo: {groupName}',
  'Manage groups' => 'Gestionar grupos',
  'Manage profile attributes' => 'Gestionar atributos de perfil',
  'Member since' => 'Miembro desde',
  'Members' => 'Miembros',
  'Members can invite external users by email' => 'Los miembros pueden invitar a usuarios externos por correo electrónico',
  'Message' => 'Mensaje',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'El valor mínimo son 20 segundos. Si la casilla está vacía, la sesión se terminará automáticamente después de 1400 segundos (24 minutos) si no hay actividad.',
  'New approval requests' => 'Nuevas peticiones de aprobación',
  'New users can register' => 'Los usuarios anónimos pueden registrarse',
  'No' => 'No',
  'No value found!' => '¡Valor no encontrado!',
  'None' => 'Ninguno',
  'Not visible' => 'No visible',
  'One or more user needs your approval as group admin.' => 'Uno o más usuarios necesita tu aprobación como administrador del grupo.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Sólo aplicable cuando hay acceso limitado activado para los usuarios no autentificados. Sólo afecta a los usuarios nuevos.',
  'Overview' => 'Resumen',
  'Password' => 'Clave',
  'Pending approvals' => 'Aprobaciones pendientes',
  'Pending user approvals' => 'Aprobaciones de usuario pendientes',
  'People' => 'Gente',
  'Permanently delete' => 'Borrar permanentemente',
  'Permissions' => 'Permisos',
  'Prioritised User Group' => 'Grupo de usuarios prioritario',
  'Profile Permissions' => 'Permisos de perfil',
  'Profiles' => 'Perfiles',
  'Protected' => 'Protegido',
  'Protected group can not be deleted!' => '¡Un grupo protegido no puede borrarse!',
  'Remove from group' => 'Remover del grupo',
  'Require group admin approval after registration' => 'Requerir aprobación del administrador del grupo después de registrarse',
  'Resend invitation email' => 'Reenviar mensaje de invitación',
  'Save' => 'Guardar',
  'Search by name, email or id.' => 'Buscar por nombre, email o id',
  'Select Groups' => 'Seleccionar grupos',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => 'Seleccione un grupo prioritario cuyos miembros serán mostrados antes que los demás cuando se seleccione la ordenación por defecto. Los usuarios de ese grupo y los de fuera del grupo se ordenarán además por su último acceso.',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => 'Seleccione qué información de usuario será mostrada en la vista de “Personas”. Puede seleccionar cualquier campo del perfil, incluso los que se hayan creado individualmente.',
  'Send & decline' => 'Enviar y rechazar',
  'Send & save' => 'Enviar y guardar',
  'Send invitation email' => 'Enviar mensaje de invitación',
  'Send invitation email again?' => '¿Reenviar el mensaje de invitación?',
  'Send invite' => 'Enviar invitación',
  'Send notifications to users when added to or removed from the group.' => 'Enviar notificaciones a los usuarios cuando se les añada o elimine del grupo.',
  'Settings' => 'Ajustes',
  'Show group selection at registration' => 'Mostrar selección de grupo al registrarse',
  'Subject' => 'Asunto',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'Se actualizarán las pertenencias al espacio de todos los grupos. Esta operación puede tardar varios minutos.',
  'The following list contains all pending sign-ups and invites.' => 'La lista siguiente contiene todos los registros e invitaciones pendientes.',
  'The following list contains all registered users awaiting an approval.' => 'La siguiente lista contiene todos los usuarios registrados que esperan una aprobación.',
  'The selected invitations have been successfully deleted!' => 'Se han eliminado con éxito las invitaciones pendientes seleccionadas.',
  'The user is the owner of these spaces:' => 'El usuario es el propietario de estos espacios:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Esta opción le permite determinar si los usuarios pueden establecer permisos individuales para sus propios perfiles.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Esta vista contiene una lista de cada usuario registrado con acciones para ver, editar y eliminar usuarios.',
  'This user owns no spaces.' => 'Este usuario no posee espacios.',
  'Unapproved' => 'Desaprobado',
  'User deletion process queued.' => 'Se ha encolado el proceso de borrado del usuario.',
  'User is already a member of this group.' => 'Este usuario ya es miembro de este grupo.',
  'User not found!' => '¡Usuario no encontrado!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Los usuarios pueden asignarse a diferentes grupos (por ejemplo, equipos, departamentos, etc.) con espacios estándar específicos, administradores de grupo y permisos.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Al utilizar esta opción cualquier contribución (p. ej. contenidos, comentarios o “me gusta”) de este usuario se borrará de forma irrecuperable.',
  'View profile' => 'Ver perfil',
  'Visible for members only' => 'Visible para miembros únicamente',
  'Visible for members+guests' => 'Visible para miembros + invitados',
  'Will be used as a filter in \'People\'.' => 'Se utilizará como filtro en “Personas”.',
  'Yes' => 'Sí',
  'You can only delete empty categories!' => '¡Sólo puedes borrar categorías vacias!',
  'You cannot delete yourself!' => '¡No te puedes borrar a tí mismo!',
  'never' => 'Nunca',
);
